'''
encoding:   -*- coding: utf-8 -*-
@Time           :  2024/9/27 8:05
@Project_Name   :  SendEmail
@Author         :  lhw
@File_Name      :  __init__.py

功能描述

实现步骤

'''
from .send import *

__all__ = [
    'SendEmail',
]